# Table of Contents

- [ai-agent-discovery](<./ai-agent-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AI Agent Discovery](<./AI-Agent-Discovery.md>)
  - [Overview](<./AI-Agent-Discovery/Overview.md>)
  - [Benefits](<./AI-Agent-Discovery/Benefits.md>)
  - [Prerequisites](<./AI-Agent-Discovery/Prerequisites.md>)
  - [Available Integrations](<./AI-Agent-Discovery/Available-Integrations.md>)
  - [AI Agent Discovery Inbox](<./AI-Agent-Discovery/AI-Agent-Discovery-Inbox.md>)
  - [Getting Started with AI Agent Discovery](<./AI-Agent-Discovery/Getting-Started-with-AI-Agent-Discovery.md>)
